@@ -12,7 +12,7 @@ Python libraries, though it does make heavy use of external packaging commands.
 Visit <https://github.com/datalad/datalad-installer> for more information.
 """
 
-__version__ = "0.5.2"
+__version__ = "0.5.3"
 __author__ = "The DataLad Team and Contributors"
 __author_email__ = "team@datalad.org"
 __license__ = "MIT"
@@ -1589,7 +1589,7 @@ class SnapshotInstaller(AutobuildSnapshotInstaller):
         if ON_LINUX:
             binpath = self._install_linux("linux/current")
         elif ON_MACOS:
-            binpath = self._install_macos("OSX/current/10.10_Yosemite")
+            binpath = self._install_macos("OSX/current/10.15_Catalina")
         else:
             raise AssertionError("Method should not be called on unsupported platforms")
         log.debug("Installed program directory: %s", binpath)
